#[non_exhaustive]pub enum SchemeSystem {
Base16,
Base24,
Tinted8,
}Expand description
Enum representing the scheme system. This enum is non-exhaustive, meaning additional variants may be added in future versions without it being considered a breaking change.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Base16
Base16 scheme system, the default.
Base24
Base24 scheme system.
Tinted8
Tinted8 scheme system.
Implementations