#[non_exhaustive]pub enum SchemeVariant {
Dark,
Light,
}Expand description
Enum representing variants of a color scheme (Dark or Light). This enum is non-exhaustive, meaning additional variants may be added in future versions without it being considered a breaking change.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations